import {
  Button,
  TextField,
  Box,
  Autocomplete,
  Typography,
  Paper,
  Tooltip,
  Dialog,
  DialogTitle,
  MenuItem,
  Menu as MuiMenu,
} from "@mui/material";
import {
  BackButton,
  sightsStore,
  TabPanel,
  languageStore,
  CreateSight,
  Language,
  cityStore,
  CoordinatesInput,
  editSightStore,
  SelectMediaDialog,
  PreviewMediaDialog,
} from "@shared";
import { LanguageSwitcher } from "@widgets";
import { Info, ImagePlus } from "lucide-react";

import { observer } from "mobx-react-lite";
import { useRef, useState } from "react";

// Мокап для всплывающей подсказки

export const InformationTab = observer(
  ({ value, index }: { value: number; index: number }) => {
    const { cities } = cityStore;
    const [isMediaModalOpen, setIsMediaModalOpen] = useState(false);
    const [mediaId, setMediaId] = useState<string>("");
    const [isPreviewMediaOpen, setIsPreviewMediaOpen] = useState(false);
    const { createSight, updateCreateSight, createSightAction } = sightsStore;
    const { sightInfo } = editSightStore;
    const [city, setCity] = useState<number>(sightInfo.city_id ?? 0);
    const [coordinates, setCoordinates] = useState({
      latitude: sightInfo.latitude ?? 0,
      longitude: sightInfo.longitude ?? 0,
    });
    const { language } = languageStore;
    const token = localStorage.getItem("token");

    // Menu state for each media button
    const [menuAnchorEl, setMenuAnchorEl] = useState<null | HTMLElement>(null);
    const [activeMenuType, setActiveMenuType] = useState<
      "thumbnail" | "watermark_lu" | "watermark_rd" | null
    >(null);
    const [isAddMediaOpen, setIsAddMediaOpen] = useState(false);

    const handleMenuOpen = (
      event: React.MouseEvent<HTMLElement>,
      type: "thumbnail" | "watermark_lu" | "watermark_rd"
    ) => {
      setMenuAnchorEl(event.currentTarget);
      setActiveMenuType(type);
    };

    const handleMenuClose = () => {
      setMenuAnchorEl(null);
      setActiveMenuType(null);
    };

    const handleCreateNew = () => {
      handleMenuClose();
    };

    const handleAddMedia = () => {
      setIsAddMediaOpen(true);
      handleMenuClose();
    };

    const handleMediaSelect = (selectedMediaId: string) => {
      if (!activeMenuType) return;

      // Close the dialog
      setIsAddMediaOpen(false);
      setActiveMenuType(null);
    };

    const handleChange = (
      language: Language,
      content: Partial<CreateSight[Language]>
    ) => {
      updateCreateSight(language, content);
    };

    const handleSave = async () => {
      try {
        await createSightAction(city, coordinates);
      } catch (error) {
        console.error(error);
      }
    };

    return (
      <>
        <TabPanel value={value} index={index}>
          <Box
            sx={{
              display: "flex",
              flexDirection: "column",
              gap: 3,
              position: "relative",
              paddingBottom: "70px" /* Space for save button */,
            }}
          >
            <BackButton />

            <Box
              sx={{
                display: "flex",

                gap: 4, // Added gap between the two main columns
                width: "100%",
                flexDirection: "column",
              }}
            >
              {/* Left column with main fields */}
              <Box
                sx={{
                  flexGrow: 1,
                  display: "flex",
                  width: "80%",
                  flexDirection: "column",
                  gap: 2.5,
                }}
              >
                <TextField
                  label={`Название (${language.toUpperCase()})`}
                  value={sightInfo[language]?.info?.name ?? ""}
                  onChange={(e) => {
                    handleChange(language as Language, {
                      name: e.target.value,
                    });
                  }}
                  fullWidth
                  variant="outlined"
                />

                <TextField
                  label="Адрес"
                  value={sightInfo[language]?.info?.address ?? ""}
                  onChange={(e) => {
                    handleChange(language as Language, {
                      address: e.target.value,
                    });
                  }}
                  fullWidth
                  variant="outlined"
                />

                <Autocomplete
                  options={cities}
                  value={cities.find((city) => city.id === sightInfo.city_id)}
                  getOptionLabel={(option) => option.name}
                  onChange={(_, value) => {
                    setCity(value?.id ?? 0);
                  }}
                  renderInput={(params) => (
                    <TextField {...params} label="Город" />
                  )}
                />

                <CoordinatesInput
                  initialValue={coordinates}
                  setValue={setCoordinates}
                />
              </Box>

              <Box
                sx={{
                  display: "flex",

                  gap: 4,
                }}
              >
                <Box
                  sx={{
                    display: "flex",
                    justifyContent: "space-around",
                    width: "80%",
                    gap: 2,
                    flexDirection: { xs: "column", sm: "row" }, // Stack on extra small, side-by-side on small and up
                  }}
                >
                  <Paper
                    elevation={2}
                    sx={{
                      padding: 2,
                      display: "flex",
                      flexDirection: "column",
                      alignItems: "center",
                      gap: 1,
                      flex: 1,
                      minWidth: 150, // Ensure a minimum width
                    }}
                  >
                    <Box sx={{ display: "flex", alignItems: "center" }}>
                      <Typography
                        variant="subtitle2"
                        gutterBottom
                        sx={{ mb: 0, mr: 0.5 }}
                      >
                        Логотип
                      </Typography>
                    </Box>
                    <Box
                      sx={{
                        width: 80,
                        height: 80,
                        backgroundColor: "grey.200",
                        display: "flex",
                        alignItems: "center",
                        justifyContent: "center",
                        borderRadius: 1,
                        mb: 1,
                        cursor: editSightStore.sightInfo?.thumbnail
                          ? "pointer"
                          : "default", // Only clickable if there's an image
                        "&:hover": {
                          backgroundColor: editSightStore.sightInfo?.thumbnail
                            ? "red.300"
                            : "grey.200",
                        },
                      }}
                      onClick={() => {
                        setIsMediaModalOpen(true);
                      }}
                    >
                      {editSightStore.sightInfo?.thumbnail ? (
                        <img
                          src={`${import.meta.env.VITE_KRBL_MEDIA}${
                            editSightStore.sightInfo?.thumbnail
                          }/download?token=${token}`}
                          alt="Логотип"
                          style={{ maxWidth: "100%", maxHeight: "100%" }}
                          onClick={() => {
                            setIsPreviewMediaOpen(true);
                            setMediaId(editSightStore.sightInfo?.thumbnail);
                          }}
                        />
                      ) : (
                        <ImagePlus size={24} color="grey" />
                      )}
                    </Box>
                    <Button
                      variant="outlined"
                      size="small"
                      onClick={(e) => handleMenuOpen(e, "thumbnail")}
                    >
                      Выбрать
                    </Button>
                  </Paper>
                  <Paper
                    elevation={2}
                    sx={{
                      padding: 2,
                      display: "flex",
                      flexDirection: "column",
                      alignItems: "center",
                      gap: 1,
                      flex: 1,
                      minWidth: 150, // Ensure a minimum width
                    }}
                  >
                    <Box sx={{ display: "flex", alignItems: "center" }}>
                      <Typography
                        variant="subtitle2"
                        gutterBottom
                        sx={{ mb: 0, mr: 0.5 }}
                      >
                        Водяной знак (л.в)
                      </Typography>
                      <Tooltip title={"asf"}>
                        <Info
                          size={16}
                          color="gray"
                          style={{ cursor: "pointer" }}
                        />
                      </Tooltip>
                    </Box>
                    <Box
                      sx={{
                        width: 80,
                        height: 80,
                        backgroundColor: "grey.200",
                        display: "flex",
                        alignItems: "center",
                        justifyContent: "center",
                        borderRadius: 1,
                        mb: 1,
                        cursor: editSightStore.sightInfo?.watermark_lu
                          ? "pointer"
                          : "default", // Only clickable if there's an image
                        "&:hover": {
                          backgroundColor: editSightStore.sightInfo
                            ?.watermark_lu
                            ? "grey.300"
                            : "grey.200",
                        },
                      }}
                      onClick={() => {
                        setIsPreviewMediaOpen(true);
                        setMediaId(editSightStore.sightInfo?.watermark_lu);
                      }}
                    >
                      {editSightStore.sightInfo?.watermark_lu ? (
                        <img
                          src={`${import.meta.env.VITE_KRBL_MEDIA}${
                            editSightStore.sightInfo?.watermark_lu
                          }/download?token=${token}`}
                          alt="Знак л.в"
                          style={{ maxWidth: "100%", maxHeight: "100%" }}
                          onClick={() => {
                            setIsMediaModalOpen(true);
                            setMediaId(editSightStore.sightInfo?.watermark_lu);
                          }}
                        />
                      ) : (
                        <ImagePlus size={24} color="grey" />
                      )}
                    </Box>
                    <Button
                      variant="outlined"
                      size="small"
                      onClick={(e) => handleMenuOpen(e, "watermark_lu")}
                    >
                      Выбрать
                    </Button>
                  </Paper>

                  <Paper
                    elevation={2}
                    sx={{
                      padding: 2,
                      display: "flex",
                      flexDirection: "column",
                      alignItems: "center",
                      gap: 1,
                      flex: 1,
                      minWidth: 150, // Ensure a minimum width
                    }}
                  >
                    <Box sx={{ display: "flex", alignItems: "center" }}>
                      <Typography
                        variant="subtitle2"
                        gutterBottom
                        sx={{ mb: 0, mr: 0.5 }}
                      >
                        Водяной знак (п.в)
                      </Typography>
                      <Tooltip title={"asfaf"}>
                        <Info
                          size={16}
                          color="gray"
                          style={{ cursor: "pointer" }}
                        />
                      </Tooltip>
                    </Box>
                    <Box
                      sx={{
                        width: 80,
                        height: 80,
                        backgroundColor: "grey.200",
                        display: "flex",
                        alignItems: "center",
                        justifyContent: "center",
                        borderRadius: 1,
                        mb: 1,
                        cursor: editSightStore.sightInfo?.watermark_rd
                          ? "pointer"
                          : "default", // Only clickable if there's an image
                        "&:hover": {
                          backgroundColor: editSightStore.sightInfo
                            ?.watermark_rd
                            ? "grey.300"
                            : "grey.200",
                        },
                      }}
                      onClick={() => editSightStore.sightInfo?.watermark_rd}
                    >
                      {editSightStore.sightInfo?.watermark_rd ? (
                        <img
                          src={`${import.meta.env.VITE_KRBL_MEDIA}${
                            editSightStore.sightInfo?.watermark_rd
                          }/download?token=${token}`}
                          alt="Знак п.в"
                          style={{ maxWidth: "100%", maxHeight: "100%" }}
                          onClick={() => {
                            setIsPreviewMediaOpen(true);
                            setMediaId(editSightStore.sightInfo?.watermark_rd);
                          }}
                        />
                      ) : (
                        <ImagePlus size={24} color="grey" />
                      )}
                    </Box>
                    <Button
                      variant="outlined"
                      size="small"
                      onClick={(e) => handleMenuOpen(e, "watermark_rd")}
                    >
                      Выбрать
                    </Button>
                  </Paper>
                </Box>
              </Box>
            </Box>

            {/* LanguageSwitcher positioned at the top right */}

            <LanguageSwitcher />

            {/* Save Button fixed at the bottom right */}
            <Box
              sx={{
                position: "absolute",
                bottom: 0,
                right: 0,
                padding: 2,
                backgroundColor: "background.paper", // To ensure it stands out over content
                width: "100%", // Take full width to cover content below it
                display: "flex",
                justifyContent: "flex-end", // Align to the right
              }}
            >
              <Button variant="contained" color="success" onClick={handleSave}>
                Сохранить
              </Button>
            </Box>
          </Box>
        </TabPanel>

        {/* Media Menu */}
        <MuiMenu
          anchorEl={menuAnchorEl}
          open={Boolean(menuAnchorEl)}
          onClose={handleMenuClose}
          anchorOrigin={{
            vertical: "top",
            horizontal: "right",
          }}
          transformOrigin={{
            vertical: "bottom",
            horizontal: "right",
          }}
        >
          <MenuItem onClick={handleCreateNew}>Создать новую</MenuItem>
          <MenuItem onClick={handleAddMedia}>Выбрать существующую</MenuItem>
        </MuiMenu>

        <SelectMediaDialog
          open={isAddMediaOpen}
          onClose={() => {
            setIsAddMediaOpen(false);
            setActiveMenuType(null);
          }}
          onSelectArticle={handleMediaSelect}
        />

        <PreviewMediaDialog
          open={isPreviewMediaOpen}
          onClose={() => setIsPreviewMediaOpen(false)}
          mediaId={mediaId}
        />
      </>
    );
  }
);
